==> nonebot_plugin_bilifan-0.2.0-py3-none-any.whl: README.md <==
<div align="center">
  <img src="https://raw.githubusercontent.com/Agnes4m/nonebot_plugin_l4d2_server/main/image/logo.png" width="180" height="180"  alt="AgnesDigitalLogo">
  <br>
  <p><img src="https://s2.loli.net/2022/06/16/xsVUGRrkbn1ljTD.png" width="240" alt="NoneBotPluginText"></p>
</div>

<div align="center">

# nonebot_plugin_bilifan
_✨自动b站粉丝牌✨_

<a href="https://github.com/Agnes4m/nonebot_plugin_bilifan/stargazers">
        <img alt="GitHub stars" src="https://img.shields.io/github/stars/Agnes4m/nonebot_plugin_bilifan" alt="stars">
</a>
<a href="https://github.com/Agnes4m/nonebot_plugin_bilifan/issues">
        <img alt="GitHub issues" src="https://img.shields.io/github/issues/Agnes4m/nonebot_plugin_bilifan" alt="issues">
</a>
<a href="https://jq.qq.com/?_wv=1027&k=HdjoCcAe">
        <img src="https://img.shields.io/badge/QQ%E7%BE%A4-399365126-orange?style=flat-square" alt="QQ Chat Group">
</a>
<a href="https://pypi.python.org/pypi/nonebot_plugin_bilifan">
        <img src="https://img.shields.io/pypi/v/nonebot_plugin_bilifan.svg" alt="pypi">
</a>
    <img src="https://img.shields.io/badge/python-3.9+-blue.svg" alt="python">
    <img src="https://img.shields.io/badge/nonebot-2.0.0rc4-red.svg" alt="NoneBot">
</div>

## 配置

启动一次插件，在bot路径下，"data/bilifan"文件夹内，按需求修改"users.yaml"文件

## 指令

- b站登录 - 返回b站二维码，扫码登录，绑定qq号
- 删除登录信息 - 删除登录信息和绑定
- 开始刷牌子 - 开始执行命令
- 自动刷牌子 - 添加或取消定时任务
- 取消自动刷牌子 - 取消定时任务
- 删除全部的定时任务 - [超管]删除全部的定时任务


</details>

## 🙈 其他

- 本项目仅供学习使用，请勿用于商业用途，喜欢该项目可以Star或者提供PR
- [爱发电](https://afdian.net/a/agnes_digital)
- [GPL-3.0 License](https://github.com/Agnes4m/nonebot_plugin_bilifan/blob/main/LICENSE) ©[@Agnes4m](https://github.com/Agnes4m)

## 🌐 感谢

- [新 B 站粉丝牌助手](https://github.com/XiaoMiku01/fansMedalHelper) - 源代码来自于他

==> nonebot_plugin_bilifan-0.4.0-py3-none-any.whl: README.md <==
<!-- markdownlint-disable MD024 MD026 MD031 MD033 MD036 MD041 -->
<div align="center">
  <img src="https://raw.githubusercontent.com/Agnes4m/nonebot_plugin_l4d2_server/main/image/logo.png" width="180" height="180"  alt="AgnesDigitalLogo">
  <br>
  <p><img src="https://s2.loli.net/2022/06/16/xsVUGRrkbn1ljTD.png" width="240" alt="NoneBotPluginText"></p>
</div>

<div align="center">

# nonebot_plugin_bilifan

_✨自动b站粉丝牌✨_

<a href="https://github.com/Agnes4m/nonebot_plugin_bilifan/stargazers">
        <img alt="GitHub stars" src="https://img.shields.io/github/stars/Agnes4m/nonebot_plugin_bilifan" alt="stars">
</a>
<a href="https://github.com/Agnes4m/nonebot_plugin_bilifan/issues">
        <img alt="GitHub issues" src="https://img.shields.io/github/issues/Agnes4m/nonebot_plugin_bilifan" alt="issues">
</a>
<a href="https://jq.qq.com/?_wv=1027&k=HdjoCcAe">
        <img src="https://img.shields.io/badge/QQ%E7%BE%A4-399365126-orange?style=flat-square" alt="QQ Chat Group">
</a>
<a href="https://pypi.python.org/pypi/nonebot_plugin_bilifan">
        <img src="https://img.shields.io/pypi/v/nonebot_plugin_bilifan.svg" alt="pypi">
</a>
    <img src="https://img.shields.io/badge/python-3.9+-blue.svg" alt="python">
    <img src="https://img.shields.io/badge/nonebot-2.0.0-red.svg" alt="NoneBot">
</div>

## 最新说明~~叔叔不要麻辣~~

- 已修复二维码获取sk失败的问题
- 已经更新2024.8.2粉丝牌新规则，可以正常使用了
- 新增了一个配置选项，可以设置牌子停止打卡等级，默认20级(只想无脑刷可以无视)
- alconna支持替换saa支持

## 配置说明

启动一次插件，在bot路径下，"data/bilifan"文件夹内，按需求修改"users.yaml"文件
运行跨平台使用，支持alconna下所有适配器

## 指令

- b站登录 - 返回b站二维码，扫码登录，绑定qq号
- 删除登录信息 - 删除登录信息和绑定
- 开始刷牌子 - 开始执行命令
- 自动刷牌子 - 添加或取消定时任务
- 取消自动刷牌子 - 取消定时任务
- 删除全部的定时任务 - [超管]删除全部的定时任务

</details>

## 🙈 其他

- 本项目仅供学习使用，请勿用于商业用途，喜欢该项目可以Star或者提供PR
- [爱发电](https://afdian.net/a/agnes_digital)
- [GPL-3.0 License](https://github.com/Agnes4m/nonebot_plugin_bilifan/blob/main/LICENSE) ©[@Agnes4m](https://github.com/Agnes4m)

## 🌐 感谢

- [新 B 站粉丝牌助手](https://github.com/XiaoMiku01/fansMedalHelper) - 源代码来自于他
